reagent-mui-nested-menu.shared.menu-helpers

Shared menu helpers used by MUI v5+ and Material-UI v4 variants.

Shared menu helpers used by MUI v5+ and Material-UI v4 variants.
raw docstring

opposite-horizontalcljs

source

(submenu-focused? container-ref menu-container-ref)

True when the active element is a direct child of the open sub-menu container.

True when the active element is a direct child of the open sub-menu
container.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries