Nested MUI menu components for Reagent.
Public API: nested-menu (dropdown), context-menu (right-click),
nested-menu-item / icon-menu-item (low-level), menu-items-from-data
(build menus from data) and the chevron-right / chevron-down icons.
Uses legacy Material-UI v4 subpath imports (e.g. @material-ui/core/Menu).
Nested MUI menu components for Reagent. Public API: `nested-menu` (dropdown), `context-menu` (right-click), `nested-menu-item` / `icon-menu-item` (low-level), `menu-items-from-data` (build menus from data) and the `chevron-right` / `chevron-down` icons. Uses legacy Material-UI v4 subpath imports (e.g. @material-ui/core/Menu).
(chevron-down props)Down-pointing chevron used as the dropdown button end-icon. Pass
:expanded? true to rotate it 180°.
Down-pointing chevron used as the dropdown button end-icon. Pass `:expanded?` true to rotate it 180°.
(chevron-right props)Right-pointing chevron used as the default sub-menu indicator.
Right-pointing chevron used as the default sub-menu indicator.
Wrap children so right-click opens a nested menu at pointer position.
Accepts :items, :menu-props, and :direction.
Wrap `children` so right-click opens a nested menu at pointer position. Accepts `:items`, `:menu-props`, and `:direction`.
(icon-menu-item item-opts)A single MenuItem with optional icons and a label.
Supports :label, :render-label, :left-icon, :right-icon,
:on-click, :disabled, :selected, :style, :sx,
:menu-item-props, :ref, and :class.
A single `MenuItem` with optional icons and a label. Supports `:label`, `:render-label`, `:left-icon`, `:right-icon`, `:on-click`, `:disabled`, `:selected`, `:style`, `:sx`, `:menu-item-props`, `:ref`, and `:class`.
Turn a vector of item maps into a seq of nested-menu-item /
icon-menu-item elements.
Leaves call :callback with [event item] and then invoke :close!.
Turn a vector of item maps into a seq of `nested-menu-item` / `icon-menu-item` elements. Leaves call `:callback` with `[event item]` and then invoke `:close!`.
Dropdown button that opens a (possibly nested) menu.
Accepts :items, :label, :button-props, :menu-props, :direction,
:value (for leaf highlighting), and :on-click.
Dropdown button that opens a (possibly nested) menu. Accepts `:items`, `:label`, `:button-props`, `:menu-props`, `:direction`, `:value` (for leaf highlighting), and `:on-click`.
A MenuItem that opens a nested Menu on hover/focus.
Supports recursive :items, keyboard navigation, optional open :delay,
selection highlighting with :selected-value, and close propagation
through :close!.
A `MenuItem` that opens a nested `Menu` on hover/focus. Supports recursive `:items`, keyboard navigation, optional open `:delay`, selection highlighting with `:selected-value`, and close propagation through `:close!`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |