Shared menu helpers used by MUI v5+ and Material-UI v4 variants.
Shared menu helpers used by MUI v5+ and Material-UI v4 variants.
(submenu-focused? container-ref menu-container-ref)True when the active element is a direct child of the open sub-menu container.
True when the active element is a direct child of the open sub-menu container.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |